package com.ekexiu.portal.dao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.orm.annotation.dao.DAO;
import org.jfw.apt.orm.annotation.dao.method.OrderBy;
import org.jfw.apt.orm.annotation.dao.method.Where;
import org.jfw.apt.orm.annotation.dao.method.operator.Insert;
import org.jfw.apt.orm.annotation.dao.method.operator.LimitSelect;
import org.jfw.apt.orm.annotation.dao.method.operator.SelectList;
import org.jfw.apt.orm.annotation.dao.method.operator.SelectOne;
import org.jfw.apt.orm.annotation.dao.param.LessThan;
import org.jfw.apt.orm.annotation.dao.param.Like;

import com.ekexiu.portal.po.GrowthLog;
import com.ekexiu.portal.pojo.InviteUserScore;

@DAO
public abstract class GrowthLogDao {
	@Insert
	public abstract int insert(Connection con,GrowthLog growthLog)throws SQLException;
	
	@SelectList
	public abstract List<GrowthLog> queryOperate(Connection con,String professorId,String operate)throws SQLException;
	
	@SelectOne
	@Nullable
	public abstract GrowthLog querySignIn(Connection con,String professorId,String operate,@Like String createTime)throws SQLException;
	
	public GrowthLog queryLastSignIn(Connection con,String professorId,String operate)throws SQLException{
		int index = 1;
		String sql = "SELECT ID,PROFESSOR_ID,OPERATE,SCORE,SIGN_IN_DAYS,INVITE_PRO,CREATE_TIME FROM GROWTH_LOG WHERE PROFESSOR_ID = ? AND OPERATE = ? ORDER BY CREATE_TIME DESC LIMIT 1";
		PreparedStatement ps = con.prepareStatement(sql);
		try{
			ps.setString(index++, professorId);
			ps.setString(index++, operate);
			ResultSet rs = ps.executeQuery();
			try{
				if(rs.next()){
                    GrowthLog growthLog = new GrowthLog();
                    growthLog.setId(rs.getString(1));
                    growthLog.setProfessorId(rs.getString(2));
                    String oper = rs.getString(3);
                    if(rs.wasNull()){
                    	oper = null;
                    }
                    growthLog.setOperate(oper);
                    Integer score = rs.getInt(4);
                    if(rs.wasNull()){
                    	score = null;
                    }
                    growthLog.setScore(score);
                    Integer signInDays = rs.getInt(5);
                    if(rs.wasNull()){
                    	signInDays = null;
                    }
                    growthLog.setSignInDays(signInDays);
                    String invitePro = rs.getString(6);
                    if(rs.wasNull()){
                    	invitePro = null;
                    }
                    growthLog.setInvitePro(invitePro);
                    growthLog.setCreateTime(rs.getString(7));
                    return growthLog;
                }else{
                    return null;
                }
			}finally{
				try{rs.close();}catch(Exception e1){}
			}
		}finally{
            try{ps.close();}catch(Exception e2){}
        }
	}
	
	@LimitSelect
	@OrderBy("ORDER BY CREATE_TIME DESC")
	@Where("INVITE_PRO IS NULL")
	public abstract List<GrowthLog> queryList(Connection con,String professorId,@LessThan String createTime,int rows)throws SQLException;
	
	public List<InviteUserScore> queryInvite(Connection con,String professorId,int rows,int offset) throws SQLException{
        int index = 1;
        String sql = "SELECT INVITE_PRO,SUM(SCORE) S FROM GROWTH_LOG WHERE PROFESSOR_ID = ? AND INVITE_PRO IS NOT NULL GROUP BY INVITE_PRO ORDER BY S DESC LIMIT "+ rows + " OFFSET " + offset;
        PreparedStatement ps = con.prepareStatement(sql);
        try{
            ps.setString(index++,professorId);
            ResultSet rs = ps.executeQuery();
            try{
                List<InviteUserScore> inviteUserScores = new ArrayList<InviteUserScore>();
                while(rs.next()){
                    InviteUserScore inviteUserScore =  new InviteUserScore();
                    inviteUserScore.setInviteUser(rs.getString(1));
                    inviteUserScore.setScore(rs.getInt(2));
                    inviteUserScores.add(inviteUserScore);
                }
                return inviteUserScores;
            }finally{
                try{rs.close();}catch(Exception e1){}
            }
        }finally{
            try{ps.close();}catch(Exception e2){}
        }
    }
	
	public int queryInviteScore(Connection con,String professorId)throws SQLException{
		int index = 1;
		String sql = "SELECT SUM(SCORE) FROM GROWTH_LOG WHERE PROFESSOR_ID = ? AND INVITE_PRO IS NOT NULL";
		PreparedStatement ps = con.prepareStatement(sql);
		try{
			ps.setString(index++, professorId);
			ResultSet rs = ps.executeQuery();
			try{
				if(rs.next()){
                    return rs.getInt(1);
                }else{
                    return 0;
                }
			}finally{
				try{rs.close();}catch(Exception e1){}
			}
		}finally{
			try{ps.close();}catch(Exception e2){}
		}
	}
	
	public int queryMyScore(Connection con,String professorId)throws SQLException{
		int index = 1;
		String sql = "SELECT SUM(SCORE) FROM GROWTH_LOG WHERE PROFESSOR_ID = ? AND INVITE_PRO IS NULL";
		PreparedStatement ps = con.prepareStatement(sql);
		try{
			ps.setString(index++, professorId);
			ResultSet rs = ps.executeQuery();
			try{
				if(rs.next()){
                    return rs.getInt(1);
                }else{
                    return 0;
                }
			}finally{
				try{rs.close();}catch(Exception e1){}
			}
		}finally{
			try{ps.close();}catch(Exception e2){}
		}
	}
	
	@SelectList
	@Where("(OPERATE = '2' OR OPERATE = '3' OR OPERATE = '4')")
	public abstract List<GrowthLog> queryShare(Connection con,String professorId,@Like String createTime)throws SQLException;
	
}
